# eric7.RemoteServer

Package implementing the components of the eric-ide remote server.

### Modules

EricRequestCategory | Module implementing an enum for the various service categories.
EricServer | Module implementing the eric remote server.
EricServerBaseRequestHandler | Module implementing the request handler base class of the eric-ide server.
EricServerCoverageRequestHandler | Module implementing the code coverage request handler of the eric-ide server.
EricServerDebuggerRequestHandler | Module implementing the debugger request handler of the eric-ide server.
EricServerEditorConfigRequestHandler | Module implementing the editor config request handler of the eric-ide server.
EricServerFileSystemRequestHandler | Module implementing the file system request handler of the eric-ide server.